@@ -2,6 +2,7 @@ package docker
 
 import (
 	"context"
+	"encoding/base64"
 	"encoding/json"
 	"fmt"
 	"os"
@@ -406,7 +407,7 @@ func (p *Platform) resourceContainerCreate(
 	netState *Resource_Network,
 ) error {
 	// Pull the image
-	err := p.pullImage(cli, log, ui, img, p.config.ForcePull)
+	err := p.pullImage(cli, log, ui, img, p.config.ForcePull, p.config.Auth)
 	if err != nil {
 		return status.Errorf(codes.FailedPrecondition,
 			"unable to pull image from Docker registry: %s", err)
@@ -687,7 +688,7 @@ func (p *Platform) getDockerClient(ctx context.Context) (*client.Client, error)
 	return cli, nil
 }
 
-func (p *Platform) pullImage(cli *client.Client, log hclog.Logger, ui terminal.UI, img *Image, force bool) error {
+func (p *Platform) pullImage(cli *client.Client, log hclog.Logger, ui terminal.UI, img *Image, force bool, authConfig *Auth) error {
 	in := fmt.Sprintf("%s:%s", img.Image, img.Tag)
 	args := filters.NewArgs()
 	args.Add("reference", in)
@@ -716,15 +717,24 @@ func (p *Platform) pullImage(cli *client.Client, log hclog.Logger, ui terminal.U
 
 	s.Update("Pulling Docker Image " + in)
 
-	ipo := types.ImagePullOptions{}
-
-	// if the username and password is not null make an authenticated
-	// image pull
-	/*
-		if image.Username != "" && image.Password != "" {
-			ipo.RegistryAuth = createRegistryAuth(image.Username, image.Password)
+	var authBase64 = ""
+	//Check if auth configuration is not null
+	if (*p.config.Auth != Auth{}) {
+		auth := types.AuthConfig{
+			Username:      authConfig.Username,
+			Password:      authConfig.Password,
+			Email:         authConfig.Email,
+			Auth:          authConfig.Auth,
+			ServerAddress: authConfig.ServerAddress,
+			IdentityToken: authConfig.IdentityToken,
+			RegistryToken: authConfig.RegistryToken,
 		}
-	*/
+		authBytes, _ := json.Marshal(auth)
+		authBase64 = base64.URLEncoding.EncodeToString(authBytes)
+	}
+	ipo := types.ImagePullOptions{
+		RegistryAuth: authBase64,
+	}
 
 	named, err := reference.ParseNormalizedNamed(in)
 	if err != nil {
@@ -780,6 +790,9 @@ type PlatformConfig struct {
 	// Force pull the image from the remote repository
 	ForcePull bool `hcl:"force_pull,optional"`
 
+	// Authenticates to private registry
+	Auth *Auth `hcl:"auth,block"`
+
 	// A map of key/value pairs, stored in docker as a string. Each key/value pair must
 	// be unique. Validiation occurs at the docker layer, not in Waypoint. Label
 	// keys are alphanumeric strings which may contain periods (.) and hyphens (-).
@@ -935,6 +948,19 @@ deploy {
 		docs.Default("false"),
 	)
 
+	doc.SetField(
+		"auth",
+		"the authentication information to log into the docker repository",
+		docs.SubFields(func(d *docs.SubFieldDoc) {
+			d.SetField("hostname", "Hostname of Docker registry")
+			d.SetField("username", "Username of Docker registry account")
+			d.SetField("password", "Password of Docker registry account")
+			d.SetField("serverAddress", "Address of Docker registry")
+			d.SetField("identityToken", "Token used to authenticate user")
+			d.SetField("registryToken", "Bearer tokens to be sent to Docker registry")
+		}),
+	)
+
 	doc.SetField(
 		"client_config",
 		"client config for remote Docker engine",
