@@ -154,7 +154,7 @@ func (b *Builder) Config() (interface{}, error) {
 
 // We use the struct form of arguments so that we can access named
 // values (such as "HasRegistry").
-type buildArgs struct {
+type BuildArgs struct {
 	argmapper.Struct
 
 	Ctx         context.Context
@@ -183,7 +183,7 @@ func (b *Builder) BuildODR(
 }
 
 // Build
-func (b *Builder) Build(args buildArgs) (*wpdocker.Image, error) {
+func (b *Builder) Build(args BuildArgs) (*wpdocker.Image, error) {
 	// Pull all the args out to top-level values. This is mostly done
 	// cause the struct was added later, but also because these are very common.
 	ctx := args.Ctx
