@@ -3,12 +3,10 @@ package cli
 import (
 	"fmt"
 
-	"github.com/golang/protobuf/proto"
-
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
 	"github.com/hashicorp/waypoint/internal/clierrors"
 	"github.com/hashicorp/waypoint/internal/pkg/flag"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 	"github.com/posener/complete"
 )
 
@@ -54,7 +52,7 @@ func (c *AuthMethodInspectCommand) Run(args []string) int {
 		method.Oidc.ClientSecret = "[REDACTED: client secret]"
 	}
 
-	fmt.Println(proto.MarshalTextString(am))
+	fmt.Println(am.String())
 	return 0
 }
 
