@@ -24,7 +24,7 @@ func (c *SnapshotBackupCommand) initWriter(args []string) (io.Writer, io.Closer,
 			return os.Stdout, nil, nil
 		}
 
-		f, err := os.Create(args[0])
+		f, err := os.OpenFile(args[0], os.O_CREATE|os.O_EXCL, 0600)
 		if err != nil {
 			return nil, nil, err
 		}
