@@ -274,10 +274,8 @@ func (s *Server) uploadEntrypoint() error {
 		s.Logger.Debug("entrypoint layer already exists, not reuploading")
 		return nil
 	}
-
 	s.Logger.Debug("uploading entrypoint layer")
-	_, err = s.writeBlob(s.entrypointRepo, s.entrypointData)
-	if err != nil {
+	if _, err := s.writeBlob(s.entrypointRepo, s.entrypointData); err != nil {
 		return err
 	}
 
@@ -477,7 +475,7 @@ func (s *Server) writeBlob(name string, data []byte) (digest.Digest, error) {
 	defer resp.Body.Close()
 
 	if resp.StatusCode >= 300 {
-		return "", fmt.Errorf("Error starting blob upload: %s", resp.Status)
+		return "", fmt.Errorf("error starting blob upload: %s", resp.Status)
 	}
 
 	loc := resp.Header.Get("Location")
@@ -501,7 +499,7 @@ func (s *Server) writeBlob(name string, data []byte) (digest.Digest, error) {
 	defer resp.Body.Close()
 
 	if resp.StatusCode != 201 {
-		return "", fmt.Errorf("error attempting to entrypoint layer: %s", resp.Status)
+		return "", fmt.Errorf("error attempting to put entrypoint layer: %s", resp.Status)
 	}
 
 	return dig, nil
@@ -564,15 +562,6 @@ func (s *Server) updateManifest(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 
-	// Ok, now delete the config from the jsonBlobs and upload any remaining json
-	// blobs so the upstream knows about them.
-
-	delete(s.jsonBlobs, conKey)
-
-	for id, data := range s.jsonBlobs {
-		s.writeBlob(id, data)
-	}
-
 	var config v1.Image
 	err = json.Unmarshal(configData, &config)
 	if err != nil {
@@ -583,22 +572,32 @@ func (s *Server) updateManifest(w http.ResponseWriter, r *http.Request) {
 
 	// detect if the entrypoint injection already took place
 
+	// injectEntrypoint is used to determine if the image has or should have
+	// Entrypoint injected.
+	injectEntrypoint := true
 	for _, h := range config.History {
 		if h.CreatedBy == createdBy {
-			r.Body = ioutil.NopCloser(bytes.NewReader(data))
-			s.proxy(w, r)
-			return
+			injectEntrypoint = false
 		}
 	}
 
+	// Ok, now delete the config from the jsonBlobs and upload any remaining json
+	// blobs so the upstream knows about them.
+	delete(s.jsonBlobs, conKey)
+	for id, data := range s.jsonBlobs {
+		s.writeBlob(id, data)
+	}
+
 	now := time.Now()
 
-	config.RootFS.DiffIDs = append(config.RootFS.DiffIDs, s.entrypointDiffId)
-	config.History = append(config.History, v1.History{
-		Created:   &now,
-		CreatedBy: createdBy,
-		Author:    "waypoint",
-	})
+	if injectEntrypoint {
+		config.RootFS.DiffIDs = append(config.RootFS.DiffIDs, s.entrypointDiffId)
+		config.History = append(config.History, v1.History{
+			Created:   &now,
+			CreatedBy: createdBy,
+			Author:    "waypoint",
+		})
+	}
 
 	// By default we want to prepend waypoint-entrypoint to the Entrypoint and
 	// inject the CEB. If the Entrypoint is empty, or the first element is
@@ -631,20 +630,22 @@ func (s *Server) updateManifest(w http.ResponseWriter, r *http.Request) {
 		mediaType = dockerRootFSMediaType
 	}
 
-	// Upload it again just to be sure the layer is still there before we go and reference
-	// it. This protects against the repo deleting the layer blob between server start and
-	// here.
-	err = s.uploadEntrypoint()
-	if err != nil {
-		http.Error(w, "error uploading entrypoint", http.StatusInternalServerError)
-		return
-	}
+	if injectEntrypoint {
+		// Upload Entrypoint again just to be sure the layer is still there
+		// before we go and reference it. This protects against the repo
+		// deleting the layer blob between server start and here.
+		err := s.uploadEntrypoint()
+		if err != nil {
+			http.Error(w, "error uploading entrypoint", http.StatusInternalServerError)
+			return
+		}
 
-	man.Layers = append(man.Layers, v1.Descriptor{
-		MediaType: mediaType,
-		Digest:    s.entrypointId,
-		Size:      s.entrypointSize,
-	})
+		man.Layers = append(man.Layers, v1.Descriptor{
+			MediaType: mediaType,
+			Digest:    s.entrypointId,
+			Size:      s.entrypointSize,
+		})
+	}
 
 	newMan, err := json.MarshalIndent(man, "", "  ")
 	if err != nil {
