@@ -16,6 +16,7 @@ import (
 
 	"github.com/hashicorp/waypoint/internal/server/boltdbstate"
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
+	"github.com/hashicorp/waypoint/pkg/server/hcerr"
 	"github.com/hashicorp/waypoint/pkg/server/logbuffer"
 	"github.com/hashicorp/waypoint/pkg/server/ptypes"
 	"github.com/hashicorp/waypoint/pkg/serverstate"
@@ -37,7 +38,13 @@ func (s *Service) EntrypointConfig(
 		},
 	})
 	if err != nil {
-		return err
+		return hcerr.Externalize(
+			log,
+			err,
+			"failed to get deployment in entrypoint config",
+			"deployment_id",
+			req.DeploymentId,
+		)
 	}
 
 	// Create our record
@@ -53,8 +60,14 @@ func (s *Service) EntrypointConfig(
 		Type:         req.Type,
 		DisableExec:  req.DisableExec,
 	}
-	if err := s.state(ctx).InstanceCreate(record); err != nil {
-		return err
+	if err := s.state(ctx).InstanceCreate(ctx, record); err != nil {
+		return hcerr.Externalize(
+			log,
+			err,
+			"failed to get create an instance in entrypoint config",
+			"deployment_id",
+			req.DeploymentId,
+		)
 	}
 
 	// Handling exec requests is optional so we check if state supports
@@ -74,7 +87,7 @@ func (s *Service) EntrypointConfig(
 
 		// Delete the entrypoint first
 		log.Trace("deleting entrypoint")
-		if err := s.state(ctx).InstanceDelete(record.Id); err != nil {
+		if err := s.state(ctx).InstanceDelete(ctx, record.Id); err != nil {
 			log.Error("failed to delete instance data. This should not happen.", "err", err)
 		}
 
@@ -82,7 +95,7 @@ func (s *Service) EntrypointConfig(
 			// Delete any active but unconnected exec requests. This can happen
 			// if the entrypoint crashed after an exec was assigned to the entrypoint.
 			log.Trace("closing any unconnected exec requests")
-			execs, err := iexec.InstanceExecListByInstanceId(record.Id, nil)
+			execs, err := iexec.InstanceExecListByInstanceId(ctx, record.Id, nil)
 			if err != nil {
 				log.Error("failed to query instance exec list. This should not happen.", "err", err)
 			} else {
@@ -102,14 +115,18 @@ func (s *Service) EntrypointConfig(
 		// Get our exec requests
 		var execs []*serverstate.InstanceExec
 		if iexec != nil {
-			execs, err = iexec.InstanceExecListByInstanceId(req.InstanceId, ws)
+			execs, err = iexec.InstanceExecListByInstanceId(ctx, req.InstanceId, ws)
 			if err != nil {
-				return err
+				return hcerr.Externalize(
+					log,
+					err,
+					"failed to find an instance for exec",
+				)
 			}
 		}
 
 		// Refresh the application record in case it's been deleted
-		_, err = s.state(ctx).AppGet(deployment.Application)
+		_, err = s.state(ctx).AppGet(ctx, deployment.Application)
 		if err != nil {
 			log.Warn("detected removed application in entrypoint",
 				"project", deployment.Application.Project,
@@ -138,7 +155,7 @@ func (s *Service) EntrypointConfig(
 		}
 
 		// Get the config vars in use
-		vars, err := s.state(ctx).ConfigGetWatch(&pb.ConfigGetRequest{
+		vars, err := s.state(ctx).ConfigGetWatch(ctx, &pb.ConfigGetRequest{
 			Scope: &pb.ConfigGetRequest_Application{
 				Application: deployment.Application,
 			},
@@ -146,15 +163,23 @@ func (s *Service) EntrypointConfig(
 			Labels:    deployment.Labels,
 		}, ws)
 		if err != nil {
-			return err
+			return hcerr.Externalize(
+				log,
+				err,
+				"failed to watch config in entrypoint config",
+			)
 		}
 		config.EnvVars = vars
 
 		config.FileChangeSignal, err = s.state(ctx).GetFileChangeSignal(
-			deployment.Application,
+			ctx, deployment.Application,
 		)
 		if err != nil {
-			return err
+			return hcerr.Externalize(
+				log,
+				err,
+				"failed to get file change signal in entrypoint config",
+			)
 		}
 
 		// Get the config sources we need for our vars. We only do this if
@@ -163,14 +188,18 @@ func (s *Service) EntrypointConfig(
 			// NOTE(mitchellh): For now we query all the types and always send it
 			// all down. In the future we may want to consider filtering this
 			// by only the types we actually need above.
-			sources, err := s.state(ctx).ConfigSourceGetWatch(&pb.GetConfigSourceRequest{
+			sources, err := s.state(ctx).ConfigSourceGetWatch(ctx, &pb.GetConfigSourceRequest{
 				Scope: &pb.GetConfigSourceRequest_Application{
 					Application: deployment.Application,
 				},
 				Workspace: deployment.Workspace,
 			}, ws)
 			if err != nil {
-				return err
+				return hcerr.Externalize(
+					log,
+					err,
+					"failed to watch config source in entrypoint config",
+				)
 			}
 
 			config.ConfigSources = sources
@@ -217,7 +246,11 @@ func (s *Service) EntrypointConfig(
 		if err := srv.Send(&pb.EntrypointConfigResponse{
 			Config: config,
 		}); err != nil {
-			return err
+			return hcerr.Externalize(
+				log,
+				err,
+				"failed to send config in entrypoint config",
+			)
 		}
 
 		// Nil out the stuff we used so that if we're waiting awhile we can GC
@@ -226,7 +259,11 @@ func (s *Service) EntrypointConfig(
 
 		// Wait for any changes
 		if err := ws.WatchCtx(srv.Context()); err != nil {
-			return err
+			return hcerr.Externalize(
+				log,
+				err,
+				"failed to watch for changes in entrypoint config",
+			)
 		}
 	}
 }
@@ -243,8 +280,12 @@ func (s *Service) EntrypointLogStream(
 	// state store. We will add support for our other stores later.
 	inmemstate, ok := s.state(ctx).(*boltdbstate.State)
 	if !ok {
-		return status.Errorf(codes.Unimplemented,
-			"state storage doesn't support log streaming")
+		return hcerr.Externalize(
+			hclog.FromContext(ctx),
+			status.Errorf(codes.Unimplemented,
+				"state storage doesn't support log streaming"),
+			"state storage doesn't support log streaming",
+		)
 	}
 
 	var buf *logbuffer.Buffer
@@ -252,7 +293,11 @@ func (s *Service) EntrypointLogStream(
 		// Read the next log entry
 		batch, err := server.Recv()
 		if err != nil {
-			return err
+			return hcerr.Externalize(
+				log,
+				err,
+				"failed to receive entrypoint log",
+			)
 		}
 
 		// If we haven't initialized our buffer yet, do that
@@ -260,7 +305,7 @@ func (s *Service) EntrypointLogStream(
 			log = log.With("instance_id", batch.InstanceId)
 
 			// Read our instance record
-			instance, err := s.state(ctx).InstanceById(batch.InstanceId)
+			instance, err := s.state(ctx).InstanceById(ctx, batch.InstanceId)
 			if err != nil {
 				if status.Code(err) == codes.NotFound {
 					// See if we have a instance logs entry to use instead.
@@ -269,15 +314,23 @@ func (s *Service) EntrypointLogStream(
 					// without generating a full Instance.
 
 					log.Info("no Instance found, attempting to lookup InstanceLogs record instead")
-					il, err := inmemstate.InstanceLogsByInstanceId(batch.InstanceId)
+					il, err := inmemstate.InstanceLogsByInstanceId(ctx, batch.InstanceId)
 					if err != nil {
-						return err
+						return hcerr.Externalize(
+							log,
+							err,
+							"failed to find log by instance ID in entrypoint",
+						)
 					}
 
 					log.Info("using InstanceLogs record")
 					buf = il.LogBuffer
 				} else {
-					return err
+					return hcerr.Externalize(
+						log,
+						err,
+						"failed to find log by instance ID in entrypoint",
+					)
 				}
 			} else {
 				// Get our log buffer
@@ -316,32 +369,52 @@ func (s *Service) EntrypointExecStream(
 	// it's supported first.
 	iexec, ok := s.state(ctx).(serverstate.InstanceExecHandler)
 	if !ok {
-		return status.Errorf(codes.Unimplemented,
-			"state storage doesn't support exec streaming")
+		return hcerr.Externalize(
+			log,
+			status.Errorf(codes.Unimplemented,
+				"state storage doesn't support exec streaming"),
+			"state storage doesn't support exec streaming",
+		)
 	}
 
 	// Receive our opening message so we can determine the exec stream.
 	req, err := server.Recv()
 	if err != nil {
-		return err
+		return hcerr.Externalize(
+			log,
+			err,
+			"failed to receive entrypoint exex stream",
+		)
 	}
 	open, ok := req.Event.(*pb.EntrypointExecRequest_Open_)
 	if !ok {
-		return status.Errorf(codes.FailedPrecondition,
-			"first message must be open type")
+		return hcerr.Externalize(
+			log,
+			status.Errorf(codes.FailedPrecondition,
+				"error reading entrypoint exec stream, first message must be open type"),
+			"error reading entrypoint exec stream, first message must be open type",
+		)
 	}
 
 	// Get our instance and look for this exec index
 	exec, err := iexec.InstanceExecConnect(ctx, open.Open.Index)
 	if err != nil {
-		return err
+		return hcerr.Externalize(
+			log,
+			err,
+			"failed to connect to instance for exec",
+		)
 	}
 	log = log.With("instance_id", exec.InstanceId, "index", open.Open.Index)
 
 	// Mark we're connected
 	if !atomic.CompareAndSwapUint32(&exec.Connected, 0, 1) {
-		return status.Errorf(codes.FailedPrecondition,
-			"exec session is already open for this index")
+		return hcerr.Externalize(
+			log,
+			status.Errorf(codes.FailedPrecondition,
+				"exec session is already open for this index"),
+			"exec session is already open for this index",
+		)
 	}
 	log.Debug("exec stream open")
 
@@ -461,7 +534,11 @@ func (s *Service) EntrypointExecStream(
 			Opened: true,
 		},
 	}); err != nil {
-		return err
+		return hcerr.Externalize(
+			log,
+			err,
+			"failure to send entrypoint exec response",
+		)
 	}
 
 	// Loop through our receive loop
@@ -474,14 +551,22 @@ func (s *Service) EntrypointExecStream(
 			// Double check and see if there was an error and if so, return it.
 			select {
 			case err = <-errCh:
-				return err
+				return hcerr.Externalize(
+					log,
+					err,
+					"error in entrypoint exec stream",
+				)
 			default:
 				return nil
 			}
 
 		// The above goroutine has errored.
 		case err := <-errCh:
-			return err
+			return hcerr.Externalize(
+				log,
+				err,
+				"error in entrypoint exec stream",
+			)
 
 		// The client goroutine has finished.
 		case req, active := <-exec.ClientEventCh:
@@ -491,7 +576,11 @@ func (s *Service) EntrypointExecStream(
 			}
 
 			if err := s.handleClientExecRequest(log, server, req); err != nil {
-				return err
+				return hcerr.Externalize(
+					log,
+					err,
+					"error handling client exec request",
+				)
 			}
 		}
 	}
