@@ -4,6 +4,7 @@ import (
 	"context"
 
 	"github.com/hashicorp/go-hclog"
+
 	empty "google.golang.org/protobuf/types/known/emptypb"
 
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
@@ -20,8 +21,14 @@ func (s *Service) UpsertProject(
 	}
 
 	result := req.Project
-	if err := s.state(ctx).ProjectPut(result); err != nil {
-		return nil, err
+	if err := s.state(ctx).ProjectPut(ctx, result); err != nil {
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to upsert project",
+			"project_name",
+			result.GetName(),
+		)
 	}
 
 	if projectNeedsRemoteInit(result) {
@@ -52,15 +59,27 @@ func (s *Service) GetProject(
 		return nil, err
 	}
 
-	result, err := s.state(ctx).ProjectGet(req.Project)
+	result, err := s.state(ctx).ProjectGet(ctx, req.Project)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get project",
+			"project_name",
+			result.GetName(),
+		)
 	}
 
 	// Get all the workspaces that this project is part of
-	workspaces, err := s.state(ctx).ProjectListWorkspaces(req.Project)
+	workspaces, err := s.state(ctx).ProjectListWorkspaces(ctx, req.Project)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to list workspaces for project",
+			"project_name",
+			result.GetName(),
+		)
 	}
 
 	return &pb.GetProjectResponse{
@@ -71,14 +90,31 @@ func (s *Service) GetProject(
 
 func (s *Service) ListProjects(
 	ctx context.Context,
-	req *empty.Empty,
+	req *pb.ListProjectsRequest,
 ) (*pb.ListProjectsResponse, error) {
-	result, err := s.state(ctx).ProjectList()
-	if err != nil {
+	if err := serverptypes.ValidateListProjectsRequest(req); err != nil {
 		return nil, err
 	}
 
-	return &pb.ListProjectsResponse{Projects: result}, nil
+	count, err := s.state(ctx).ProjectCount(ctx)
+	if err != nil {
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to count projects",
+		)
+	}
+
+	result, pagination, err := s.state(ctx).ProjectList(ctx, req.Pagination)
+	if err != nil {
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to list projects",
+		)
+	}
+
+	return &pb.ListProjectsResponse{Projects: result, Pagination: pagination, TotalCount: count}, nil
 }
 
 func (s *Service) DestroyProject(
@@ -89,9 +125,15 @@ func (s *Service) DestroyProject(
 		return nil, err
 	}
 
-	err := s.state(ctx).ProjectDelete(req.Project)
+	err := s.state(ctx).ProjectDelete(ctx, req.Project)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to delete project",
+			"project",
+			req.Project.Project,
+		)
 	}
 
 	return &empty.Empty{}, nil
@@ -105,9 +147,15 @@ func (s *Service) GetApplication(
 		return nil, err
 	}
 
-	result, err := s.state(ctx).AppGet(req.Application)
+	result, err := s.state(ctx).AppGet(ctx, req.Application)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get application",
+			"application",
+			req.Application.Application,
+		)
 	}
 
 	return &pb.GetApplicationResponse{
@@ -124,9 +172,13 @@ func (s *Service) UpsertApplication(
 	}
 
 	// Get the project
-	praw, err := s.state(ctx).ProjectGet(req.Project)
+	praw, err := s.state(ctx).ProjectGet(ctx, req.Project)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get project in application upsert",
+		)
 	}
 
 	var app *pb.Application
@@ -144,16 +196,22 @@ func (s *Service) UpsertApplication(
 
 	app.FileChangeSignal = req.FileChangeSignal
 
-	app, err = s.state(ctx).AppPut(app)
+	app, err = s.state(ctx).AppPut(ctx, app)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get upsert application",
+			"application_name",
+			app.GetName(),
+		)
 	}
 
 	return &pb.UpsertApplicationResponse{Application: app}, nil
 }
 
 func queueInitOps(s *Service, ctx context.Context, project *pb.Project) error {
-	workspaces, err := s.state(ctx).WorkspaceList()
+	workspaces, err := s.state(ctx).WorkspaceList(ctx)
 	if err != nil {
 		return err
 	}
@@ -187,11 +245,15 @@ func queueInitOps(s *Service, ctx context.Context, project *pb.Project) error {
 }
 
 func projectNeedsRemoteInit(project *pb.Project) bool {
+	if project.State != pb.Project_ACTIVE {
+		return false
+	}
+
 	if project.DataSource == nil {
 		return false
 	}
 
-	if project.DataSource.GetGit() == nil {
+	if project.DataSource.GetGit() == nil && project.DataSource.GetRemote() == nil {
 		return false
 	}
 
