@@ -8,6 +8,7 @@ import (
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 	"google.golang.org/protobuf/types/known/emptypb"
+	empty "google.golang.org/protobuf/types/known/emptypb"
 
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 	serverptypes "github.com/hashicorp/waypoint/pkg/server/ptypes"
@@ -151,11 +152,13 @@ func TestServiceOnDemandRunnerConfig_GetOnDemandRunnerConfig(t *testing.T, facto
 
 	// Best way to mock for now is to make a request
 	resp, err := client.UpsertOnDemandRunnerConfig(ctx, &pb.UpsertOnDemandRunnerConfigRequest{
-		Config: serverptypes.TestOnDemandRunnerConfig(t, nil),
+		Config: serverptypes.TestOnDemandRunnerConfig(t, &pb.OnDemandRunnerConfig{Default: true}),
 	})
 
 	require.NoError(t, err)
 
+	odr := resp.Config
+
 	// Simplify writing tests
 	type Req = pb.GetOnDemandRunnerConfigRequest
 
@@ -173,6 +176,17 @@ func TestServiceOnDemandRunnerConfig_GetOnDemandRunnerConfig(t *testing.T, facto
 		require.NotEmpty(resp.Config)
 	})
 
+	t.Run("get only default", func(t *testing.T) {
+		require := require.New(t)
+
+		// Get, should return a deployment
+		resp, err := client.GetDefaultOnDemandRunnerConfig(ctx, &empty.Empty{})
+		require.NoError(err)
+		require.NotNil(resp)
+		require.NotEmpty(resp.Config)
+		require.Equal(resp.Config.Id, odr.Id)
+	})
+
 	t.Run("get non-existing", func(t *testing.T) {
 		require := require.New(t)
 
