@@ -4,6 +4,7 @@ import { action } from '@ember/object';
 import { tracked } from '@glimmer/tracking';
 import ApiService from 'waypoint/services/api';
 import FlashMessagesService from 'waypoint/services/pds-flash-messages';
+import type ProjectService from 'waypoint/services/project';
 import {
   Ref,
   ExpediteStatusReportRequest,
@@ -21,6 +22,7 @@ interface Args {
 export default class StatusReportMetaTable extends Component<Args> {
   @service api!: ApiService;
   @service('pdsFlashMessages') flashMessages!: FlashMessagesService;
+  @service declare project: ProjectService;
   @tracked isRefreshRunning = false;
 
   get artifactType(): Args['artifactType'] {
@@ -35,6 +37,11 @@ export default class StatusReportMetaTable extends Component<Args> {
     return this.model.statusReport;
   }
 
+  get projectHasDataSource(): boolean {
+    let dataSource = this.project.current?.dataSource;
+    return Boolean(dataSource && !dataSource.local);
+  }
+
   @action
   async refreshHealthCheck(e: Event): Promise<void> {
     e.preventDefault();
